@@ -1,4 +1,5 @@
 import logging
+import shutil
 import socket
 from typing import List
 
@@ -22,6 +23,12 @@ async def _get_fqdns(fqdn: str, protocol: int) -> List[str]:
 async def load_socket_info(hub):
     hub.corn.CORN.localhost = socket.gethostname()
 
+    hostname = shutil.which("hostname")
+    if hostname:
+        hub.corn.CORN.computer_name = (await hub.exec.cmd.run(hostname))["stdout"].strip()
+    else:
+        hub.corn.CORN.computer_name = hub.corn.CORN.localhost
+
     # try socket.getaddrinfo to get fqdn
     try:
         addrinfo = socket.getaddrinfo(
